EasyLogBackend class abstract interface

Implementers

Properties

currentFileObject → dynamic
no setter
directoryObject → dynamic
no setter
directoryPath String
no setter
enable bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isBinary bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
clearExpired() Future<void>
createArchive(String outputDirectory) Future<String?>
dispose() Future<void>
files() Future<List<EasyLogBackendFile>>
filesSnapshot() List<EasyLogBackendFile>
flush() Future<void>
initialize() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readCurrent() Future<String>
toString() String
A string representation of this object.
inherited
write(EasyLogBackendRecord record) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited