EasyLogBackendConfig class

Constructors

EasyLogBackendConfig({required String location, required String nameSpace, required bool enabled, required int minLevel, required int rotationHours, required int singleFileSizeBytes, required Duration retention, required int maxDiskSizeBytes})
const

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
location String
final
maxDiskSizeBytes int
final
minLevel int
final
nameSpace String
final
retention Duration
final
rotationHours int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleFileSizeBytes int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited