EasyLogBackendRecord class

Constructors

EasyLogBackendRecord({required int sequenceId, required DateTime timestamp, required int level, required String message, required String formattedMessage, String? name, String? tag, String? error, String? stackTrace})
const

Properties

error String?
final
formattedMessage String
final
hashCode int
The hash code for this object.
no setterinherited
level int
final
message String
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceId int
final
stackTrace String?
final
tag String?
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited