QueuedEasyLogBackend class abstract base

Implemented types
Implementers

Constructors

QueuedEasyLogBackend()

Properties

currentFileObject → dynamic
no setterinherited
directoryObject → dynamic
no setterinherited
directoryPath String
no setterinherited
enable bool
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isBinary bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
inherited
clearExpired() Future<void>
inherited
createArchive(String outputDirectory) Future<String?>
inherited
dispose() Future<void>
inherited
enqueue(FutureOr<void> operation()) Future<void>
enqueueResult<T>(FutureOr<T> operation()) Future<T>
files() Future<List<EasyLogBackendFile>>
inherited
filesSnapshot() List<EasyLogBackendFile>
inherited
flush() Future<void>
override
initialize() Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readCurrent() Future<String>
inherited
toString() String
A string representation of this object.
inherited
write(EasyLogBackendRecord record) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited