TextEasyLogBackend class final
FIFO plaintext persistence aligned with flutter_logger's ytj adapter.
Android and iOS intentionally use this backend too. The uploaded artifact is
the original .log file; there is no MX binary file and no export-time
decoding or conversion.
- Inheritance
-
- Object
- QueuedEasyLogBackend
- TextEasyLogBackend
Constructors
- TextEasyLogBackend(EasyLogBackendConfig _config, {EasyLogWriteFailure? onFailure})
Properties
- currentFileObject → dynamic
-
no setteroverride
- directoryObject → dynamic
-
no setteroverride
- directoryPath → String
-
no setteroverride
- enable ↔ bool
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBinary → bool
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Future< void> -
override
-
clearExpired(
) → Future< void> -
override
-
createArchive(
String outputDirectory) → Future< String?> -
override
-
dispose(
) → Future< void> -
override
-
enqueue(
FutureOr< void> operation()) → Future<void> -
inherited
-
enqueueResult<
T> (FutureOr< T> operation()) → Future<T> -
inherited
-
files(
) → Future< List< EasyLogBackendFile> > -
override
-
filesSnapshot(
) → List< EasyLogBackendFile> -
override
-
flush(
) → Future< void> -
inherited
-
initialize(
) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readCurrent(
) → Future< String> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
EasyLogBackendRecord record) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited